import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {
    Label, Input, FormGroup, FormFeedback, FormText
} from 'reactstrap';

class CheckBoxField extends Component {
    static propTypes = {
        onChange: PropTypes.func.isRequired,
        name: PropTypes.string.isRequired,
        label: PropTypes.string.isRequired,
        linkTo: PropTypes.shape({
            label: PropTypes.string,
            url: PropTypes.string,
            target: PropTypes.string
        }),
        value: PropTypes.string,
        type: PropTypes.string.isRequired,
        helpText: PropTypes.string,
        disabled: PropTypes.bool,
        error: PropTypes.shape()
    };

    static defaultProps = {
        value: null,
        helpText: null,
        disabled: false,
        error: {
            status: null
        },
        linkTo: null
    };

    handleChange({target}) {
        if (this.props.value === target.checked) {
            return;
        }
        this.props.onChange({target});
    }

    render() {
        const {
            name, label, value, type, helpText, disabled, error, linkTo
        } = this.props;

        const linkStyle = {
            color: '#53A8F8',
            textDecoration: 'underline'
        };

        return (
            <FormGroup check>
                <Label check>
                    <Input
                        valid={error.status === 'valid' ? true : null}
                        invalid={error.status === 'invalid' ? true : null}
                        id={name}
                        name={name}
                        type={type}
                        value={value}
                        disabled={disabled}
                        onChange={e => this.handleChange(e)}
                    />
                    {label}
                    {linkTo && (
                        <a
                            href={linkTo.url}
                            target={linkTo.target}
                            style={linkStyle}
                        >
                            {linkTo.label}
                        </a>
                    )}
                    <FormFeedback valid={error.status === 'valid' ? true : null}>
                        {error.message}
                    </FormFeedback>
                    <FormText>{helpText}</FormText>
                </Label>
            </FormGroup>
        );
    }
}

export default CheckBoxField;
