import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {
    Label, Input, FormGroup, FormFeedback, FormText
} from 'reactstrap';

class TextField extends Component {
    static propTypes = {
        onChange: PropTypes.func.isRequired,
        name: PropTypes.string.isRequired,
        label: PropTypes.string.isRequired,
        value: PropTypes.string,
        type: PropTypes.string.isRequired,
        helpText: PropTypes.string,
        disabled: PropTypes.bool,
        minLength: PropTypes.number,
        maxLength: PropTypes.number,
        error: PropTypes.shape(),
        onKeyPress: PropTypes.func
    };

    static defaultProps = {
        value: null,
        helpText: null,
        minLength: null,
        maxLength: null,
        error: {
            status: null
        },
        disabled: false,
        onKeyPress: null
    };

    handleChange({target}) {
        if (this.props.value === target.value) {
            return;
        }
        this.props.onChange({target});
    }

    render() {
        const {
            name, label, value, type, helpText, disabled, error, minLength, maxLength
        } = this.props;
        return (
            <FormGroup>
                <Label>{label}</Label>
                <Input
                    valid={error.status === 'valid' ? true : null}
                    invalid={error.status === 'invalid' ? true : null}
                    id={name}
                    name={name}
                    type={type}
                    value={value}
                    minLength={minLength ? minLength : null}
                    maxLength={maxLength ? maxLength : null}
                    autoComplete="off"
                    disabled={disabled}
                    onChange={e => this.handleChange(e)}
                    onKeyPress={this.props.onKeyPress}
                />
                <FormFeedback valid={error.status === 'valid' ? true : null}>
                    {error.message}
                </FormFeedback>
                <FormText>{helpText}</FormText>
            </FormGroup>
        );
    }
}

export default TextField;
